<!doctype html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="https://gmpg.org/xfn/11">
<?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<?php
$copyright = qesco_get_option( 'footer_copyright_text' );

if ( !$copyright ) {
  $copyright = esc_html__( '&copy; 2021 Qesco | Logistic Shipping Company', 'qesco' );
}

$custom_menu = qesco_get_option( 'custom_menu' );
$enable_search = ( qesco_get_option( 'disable_search' ) ) ? false : true;
$enable_topbar = ( qesco_get_option( 'disable_navbar_button' ) ) ? false : true;


$topbar_social_media = qesco_get_option( 'topbar_social_media' );
$topbar_phone = qesco_get_option( 'topbar_phone' );


$logo = ( qesco_get_option( 'logo' ) ) ? qesco_get_option( 'logo' ) : get_template_directory_uri() . '/images/logo@2x.png';
$retina_logo = ( qesco_get_option( 'retina_logo' ) ) ? qesco_get_option( 'retina_logo' ) : '';

$pre_loader_icon = get_template_directory_uri() . '/images/preloader.png';

?>
<?php
if ( qesco_get_option( 'enable_page_transition' ) ):
  ?>
<div class="preloader"> <img src="<?php echo esc_url( $pre_loader_icon ); ?>" alt="Image"> </div>
<!-- end preloader -->
<div class="page-transition"></div>
<!-- end page-transition -->

<?php endif; ?>
<aside class="side-widget">
  <div class="inner">
    <div class="logo"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $logo ); ?>"
	<?php if( $retina_logo != '' ) : ?>
		srcset="<?php echo esc_url( $retina_logo ); ?>"
	<?php endif; ?>
		alt="<?php bloginfo( 'name' ); ?>"></a></div>
    <div class="hide-mobile">
      <?php if( is_active_sidebar( 'aside-bar' ) ) : ?>
      <?php dynamic_sidebar( 'aside-bar' ); ?>
      <?php endif; ?>
    </div>
    <!-- end hide-mobile -->
    <div class="show-mobile">
      <?php
      if ( qesco_get_option( 'custom_menu' ) ):
        ?>
      <div class="custom-menu">
        <ul>
          <?php foreach ( $custom_menu as $menu ) { ?>
          <li> <a href="<?php echo esc_url( $menu['url'] ); ?>"><?php echo esc_html( $menu['label'] ); ?></a> </li>
          <?php } ?>
        </ul>
      </div>
      <?php endif; ?>
      <div class="site-menu">
        <?php
        if ( has_nav_menu( 'header' ) ) {
          wp_nav_menu( array(
            'theme_location' => 'header',
            'menu_class' => 'menu-horizontal',
            'walker' => new WP_Consto_Navwalker(),
          ) );
        }
        ?>
      </div>
    </div>
    <!-- end show-mobile --> 
    <small><?php echo esc_html( $copyright ); ?></small> </div>
  <!-- end inner --> 
</aside>
<?php
if ( qesco_get_option( 'enable_topbar' ) ):
  ?>
<div class="topbar">
  <div class="container">
    <div class="phone"><?php echo wp_kses_post( qesco_get_option( 'topbar_phone' ) ); ?></div>
    <div class="email"><?php echo wp_kses_post( qesco_get_option( 'topbar_email' ) ); ?></div>
    <div class="social-media"> <span><?php echo esc_html( qesco_get_option( 'topbar_social_label' ) ); ?></span>
      <?php
      if ( qesco_get_option( 'topbar_social_media' ) ):
        ?>
      <ul>
        <?php foreach ( $topbar_social_media as $media ) { ?>
        <li> <a href="<?php echo esc_url( $media['url'] ); ?>"><?php echo wp_kses_post( $media['icon'] ); ?> <span><?php echo wp_kses_post( $media['label'] ); ?></span></a> </li>
        <?php } ?>
      </ul>
      <!-- end social-media -->
      <?php endif; ?>
    </div>
  </div>
  <!-- end container --> 
</div>
<?php endif; ?>
<nav class="navbar">
  <div class="container">
    <div class="inner">
      <div class="logo"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $logo ); ?>"
	<?php if( $retina_logo != '' ) : ?>
		srcset="<?php echo esc_url( $retina_logo ); ?>"
	<?php endif; ?>
		alt="<?php bloginfo( 'name' ); ?>"></a></div>
      <?php
      if ( qesco_get_option( 'custom_menu' ) ):
        ?>
      <div class="custom-menu">
        <ul>
          <?php foreach ( $custom_menu as $menu ) { ?>
          <li> <a href="<?php echo esc_url( $menu['url'] ); ?>"><?php echo esc_html( $menu['label'] ); ?></a> </li>
          <?php } ?>
        </ul>
      </div>
      <?php endif; ?>
      <?php qesco_get_wpml_langs(); ?>
      <div class="site-menu">
        <?php
        if ( has_nav_menu( 'header' ) ) {
          wp_nav_menu( array(
            'theme_location' => 'header',
            'menu_class' => 'menu-horizontal',
            'walker' => new WP_Consto_Navwalker(),
          ) );
        }
        ?>
      </div>
      <?php if ( has_nav_menu( 'header' ) ) : ?>
      <div class="hamburger-menu"> <span></span> <span></span> <span></span> </div>
      <?php endif; ?>
      <?php
      if ( qesco_get_option( 'enable_navbar_button' ) ):
        ?>
      <div class="navbar-button"> <a href="<?php echo esc_url( qesco_get_option( 'navbar_button_url' ) ); ?>"><?php echo esc_html( qesco_get_option( 'navbar_button_label' ) ); ?></a> </div>
      <?php endif; ?>
    </div>
  </div>
</nav>
