<?php


if ( !function_exists( 'qesco_google_fonts_url' ) ) {
  /*
   * Register Google Font Family
   */
  function qesco_google_fonts_url() {

    wp_enqueue_style( 'qesco_google_fonts', 'https://fonts.googleapis.com/css?family=Poppins:400,600,800', false );
  }

  add_action( 'wp_enqueue_scripts', 'qesco_google_fonts_url' );

}

if ( !function_exists( 'qesco_enqueue_styles_and_scripts' ) ) {
  /**
   * This function enqueues the required css and js files.
   *
   * @return void
   */
  function qesco_enqueue_styles_and_scripts() {
    /**
     * Enqueue css files.
     */
    wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.css' );
    wp_enqueue_style( 'lineicons', get_template_directory_uri() . '/css/lineicons.css' );
    wp_enqueue_style( 'fancybox', get_template_directory_uri() . '/css/fancybox.min.css' );
    wp_enqueue_style( 'swiper', get_template_directory_uri() . '/css/swiper.min.css' );
    wp_enqueue_style( 'odometer', get_template_directory_uri() . '/css/odometer.min.css' );
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
    wp_enqueue_style( 'qesco-main-style', get_template_directory_uri() . '/css/style.css' );
    wp_enqueue_style( 'qesco-stylesheet', get_stylesheet_uri() );
    wp_add_inline_style( 'qesco-stylesheet', qesco_dynamic_css() );

    /**
     * Enqueue javascript files.
     */

    wp_enqueue_script( 'comments', get_template_directory_uri() . '/js/comments.js', array(), false, false );
    wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'fancybox', get_template_directory_uri() . '/js/fancybox.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'isotope', get_template_directory_uri() . '/js/isotope.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'odometer', get_template_directory_uri() . '/js/odometer.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'swiper', get_template_directory_uri() . '/js/swiper.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'imagesloaded', get_template_directory_uri() . '/js/imagesloaded.pkgd.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'stellar', get_template_directory_uri() . '/js/jquery.stellar.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'wow', get_template_directory_uri() . '/js/wow.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'qesco-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), false, true );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
      wp_enqueue_script( 'comment-reply' );
    }

    $data = array(
      'pre_loader_typewriter' => [],
      'audio_source' => '',
      'enable_sound_bar' => false
    );

    if ( qesco_get_option( 'enable_preloader' ) ) {
      $typewriter_text = [];
      $text_rotater = qesco_get_option( 'pre_loader_text_rotater' );
      if ( $text_rotater ) {
        foreach ( $text_rotater as $rotater ) {
          $typewriter_text[] = esc_html( $rotater[ 'title' ] );
        }
      }
      $data[ 'pre_loader_typewriter' ] = $typewriter_text;
    }


    $comment_data = array(
      'name' => esc_html__( 'Name is required', 'qesco' ),
      'email' => esc_html__( 'Email is required', 'qesco' ),
      'comment' => esc_html__( 'Comment is required', 'qesco' ),

    );

    wp_localize_script( 'qesco-scripts', 'data', $data );
    wp_localize_script( 'comments', 'comment_data', $comment_data );
  }

  add_action( 'wp_enqueue_scripts', 'qesco_enqueue_styles_and_scripts', 10 );
}

if ( !function_exists( 'qesco_dynamic_css' ) ) {
  function qesco_dynamic_css() {

    $styles = '';
    if ( qesco_get_option( 'logo_height' ) ) {
      $logo_height = str_replace( ' ', '', qesco_get_option( 'logo_height' ) );
      $logo_height = str_replace( 'px', '', $logo_height );
      $styles .= "
				.navbar .logo a img{
					height: {$logo_height}px;
				}
			";
    }
    if ( qesco_get_option( 'pageheader_height' ) ) {
      $pageheader_height = str_replace( ' ', '', qesco_get_option( 'pageheader_height' ) );
      $styles .= "
				.page-header{
					height: {$pageheader_height};
				}
			";
    }
    if ( qesco_get_option( 'enable_dynamic_color' ) ) {

      $site_color = ( qesco_get_option( 'theme_color' ) ) ? qesco_get_option( 'theme_color' ) : '#33a16e';
      $site_color2 = ( qesco_get_option( 'theme_color2' ) ) ? qesco_get_option( 'theme_color2' ) : '#fee13e';
      $body_bg_color = ( qesco_get_option( 'body_background_color' ) ) ? qesco_get_option( 'body_background_color' ) : '#009a4e';

      $styles .= "
	  
	  :root {
  --color-main: {$site_color}; 
  --color-dark: {$body_bg_color}; 
}
	  
	  
				
			";
    }

    return $styles;
  }
}


add_action( 'init', 'qesco_dynamic_css' );
add_action(
  'after_setup_theme',
  function () {
    add_theme_support( 'html5', [ 'script', 'style' ] );
  }
);